import LocaleContext from "./ak-locale-context.js";

export { LocaleContext };
export default LocaleContext;
